@@ -69,34 +69,43 @@ def load_workbook(filename, use_iterators = False):
     except (BadZipfile, RuntimeError, IOError, ValueError), e:
         raise InvalidFileException(unicode(e))
     wb = Workbook()
-    wb._set_optimized_read()
+
+    if use_iterators:
+        wb._set_optimized_read()
+
     try:
-        # get workbook-level information
-        wb.properties = read_properties_core(archive.read(ARC_CORE))
-        try:
-            string_table = read_string_table(archive.read(ARC_SHARED_STRINGS))
-        except KeyError:
-            string_table = {}
-        style_table = read_style_table(archive.read(ARC_STYLE))
-
-        # get worksheets
-        wb.worksheets = []  # remove preset worksheet
-        sheet_names = read_sheets_titles(archive.read(ARC_APP))
-        for i, sheet_name in enumerate(sheet_names):
-            sheet_codename = 'sheet%d.xml' % (i + 1)
-            worksheet_path = '%s/%s' % (PACKAGE_WORKSHEETS, sheet_codename)
-
-            if not use_iterators:
-                new_ws = read_worksheet(archive.read(worksheet_path), wb, sheet_name, string_table, style_table)
-            else:
-                xml_source = unpack_worksheet(archive, worksheet_path)
-                new_ws = read_worksheet(xml_source, wb, sheet_name, string_table, style_table, filename, sheet_codename)
-                #new_ws = read_worksheet(archive.read(worksheet_path), wb, sheet_name, string_table, style_table, filename, sheet_codename)
-            wb.add_sheet(new_ws, index = i)
-
-        wb._named_ranges = read_named_ranges(archive.read(ARC_WORKBOOK), wb)
+        _load_workbook(wb, archive, filename, use_iterators)
     except KeyError, e:
         raise InvalidFileException(unicode(e))
+    except Exception, e:
+        raise e
     finally:
         archive.close()
     return wb
+
+def _load_workbook(wb, archive, filename, use_iterators):
+
+    # get workbook-level information
+    wb.properties = read_properties_core(archive.read(ARC_CORE))
+    try:
+        string_table = read_string_table(archive.read(ARC_SHARED_STRINGS))
+    except KeyError:
+        string_table = {}
+    style_table = read_style_table(archive.read(ARC_STYLE))
+
+    # get worksheets
+    wb.worksheets = []  # remove preset worksheet
+    sheet_names = read_sheets_titles(archive.read(ARC_APP))
+    for i, sheet_name in enumerate(sheet_names):
+        sheet_codename = 'sheet%d.xml' % (i + 1)
+        worksheet_path = '%s/%s' % (PACKAGE_WORKSHEETS, sheet_codename)
+
+        if not use_iterators:
+            new_ws = read_worksheet(archive.read(worksheet_path), wb, sheet_name, string_table, style_table)
+        else:
+            xml_source = unpack_worksheet(archive, worksheet_path)
+            new_ws = read_worksheet(xml_source, wb, sheet_name, string_table, style_table, filename, sheet_codename)
+            #new_ws = read_worksheet(archive.read(worksheet_path), wb, sheet_name, string_table, style_table, filename, sheet_codename)
+        wb.add_sheet(new_ws, index = i)
+
+    wb._named_ranges = read_named_ranges(archive.read(ARC_WORKBOOK), wb)
